@@ -16,6 +16,7 @@ def subset(ds, lat, lon):
 def prepare_data(
     iter,
     outdir,
+    mask,
     lat=None,
     lon=None,
     deptht=0,
@@ -32,7 +33,7 @@ def prepare_data(
         print("Opening file:", data[0] + str(iter) + ".nc")
         ds = xr.open_dataset(data[0] + str(iter) + ".nc")
 
-    if "depth" in ds.coords:
+    if "depth" in ds[data[1]].dims:
         ds = ds.isel(depth=deptht)
 
     ds = ds[data[1]]
@@ -53,10 +54,10 @@ def prepare_data(
         climato = None
         percentile = None
 
-    compute_detection(ds, txtfile, climato, percentile, **kwargs)
+    compute_detection(ds, txtfile, mask, climato, percentile, **kwargs)
 
 
-def compute_detection(ds, txtfile, climato=None, percent=None, **kwargs):
+def compute_detection(ds, txtfile, mask=False, climato=None, percent=None, **kwargs):
 
     if "latitude" in ds.coords:
         var_lat = "latitude"
@@ -81,9 +82,13 @@ def compute_detection(ds, txtfile, climato=None, percent=None, **kwargs):
         ]
     )
 
+
     with open(txtfile, "w") as f:
         f.write("lat;lon;time_deb;time_end;time_peak;duration;duration_mod;duration_str;duration_sev;duration_ext;categ;imax;imean;ivar;rate_onset;rate_decline\n")
 
+        if mask:
+            mask_array = ds.copy()
+
         for latitude in range(0, lat):
             for longitude in range(0, lon):
 
@@ -94,9 +99,9 @@ def compute_detection(ds, txtfile, climato=None, percent=None, **kwargs):
                     temp[temp < 0] = np.nan
 
                     if (climato is None) or (percent is None):
-                        mhw_prop, mhw_date = mhw.detect(t_mhw, temp, **kwargs)
+                        mhw_prop, mhw_date, bool_mask = mhw.detect(t_mhw, temp, **kwargs)
                     else:
-                        mhw_prop, mhw_date = mhw.detect(
+                        mhw_prop, mhw_date, bool_mask = mhw.detect(
                             t_mhw,
                             temp,
                             thresh_climYear=thresh_climYear[:, latitude, longitude],
@@ -104,6 +109,9 @@ def compute_detection(ds, txtfile, climato=None, percent=None, **kwargs):
                             **kwargs
                         )
 
+                    if mask:
+                        mask_array[:, latitude, longitude] = bool_mask
+
                     if len(mhw_prop["time_start"]) != 0:
                         for num_mhw in range(len(mhw_prop["time_start"])):
                             lat_str = str(ds[var_lat][latitude].values)
@@ -122,7 +130,7 @@ def compute_detection(ds, txtfile, climato=None, percent=None, **kwargs):
                             extreme = str(mhw_prop["duration_extreme"][num_mhw])
                             onset = str(mhw_prop["rate_onset"][num_mhw])
                             decline = str(mhw_prop["rate_decline"][num_mhw])
-                          
+
                             f.write(
                                 lat_str
                                 + ";"
@@ -157,3 +165,6 @@ def compute_detection(ds, txtfile, climato=None, percent=None, **kwargs):
                                 + decline
                                 + "\n"
                             )
+
+        if mask:
+            mask_array.astype(bool).to_netcdf(txtfile+'.nc')
