@@ -2,6 +2,7 @@ import os
 import multiprocessing as mp
 from functools import partial
 import pandas as pd
+import xarray as xr
 import yaml
 import click
 from typing import Tuple
@@ -36,7 +37,14 @@ from src.mhw_detect.detection.detect import prepare_data
     + "minimal latitude, maximal latitude, "
     + "minimal longitude and maximal longitude",
 )
-def extreme_events(config: str, geographical_subset: Tuple[float, float, float, float]):
+@click.option(
+    "--generate-mask",
+    "-m",
+    type=bool,
+    help="Generate boolean mask. 1 : mhw, 0 : no mhw.",
+    default=False
+)
+def extreme_events(config: str, geographical_subset: Tuple[float, float, float, float], generate_mask: bool):
     conf = yaml.safe_load(open(config, "r"))
 
     output = conf["output_detection"]
@@ -49,13 +57,16 @@ def extreme_events(config: str, geographical_subset: Tuple[float, float, float,
         lon = geographical_subset[2:4]
 
         prepare_data(
-            0, output, lat=lat, lon=lon, p=param["pctile"], deptht=0, **data, **param
+            0, output, mask=generate_mask, lat=lat, lon=lon, p=param["pctile"], deptht=0, **data, **param
         )
 
         print("Creating csv")
         df = pd.read_csv(os.path.join(output, "0.txt"), sep=";")
         df.to_csv(os.path.join(output, "data.csv"), sep=";")
 
+        if generate_mask:
+            os.rename(output+'/0.txt.nc', output+'/mask.nc')
+
     else:
         data = parse_data(conf)
         nfile = count_files(conf)
@@ -65,7 +76,7 @@ def extreme_events(config: str, geographical_subset: Tuple[float, float, float,
 
         pool = mp.Pool()
         pool.map(
-            partial(prepare_data, outdir=output, p=param["pctile"], **data, **param),
+            partial(prepare_data, outdir=output, mask=generate_mask, p=param["pctile"], **data, **param),
             range(1, nfile),
         )
         pool.close()
@@ -82,6 +93,21 @@ def extreme_events(config: str, geographical_subset: Tuple[float, float, float,
         df = pd.concat(map(f, filepaths))
         df.to_csv(os.path.join(output, "data.csv"), sep=";")
 
+        if generate_mask:
+            mask = xr.open_mfdataset(output+'/*.nc')
+            mask.to_netcdf(output + '/mask.nc')
+            p = [
+                    os.path.join(output, str(g) + ".txt.nc")
+                    for g in range(1, nfile)
+                ]
+
+            for path in p:
+                try:
+                    os.remove(path)
+                except OSError:
+                    click.echo("Error while deleting file: ", path)
+
+
 
 if __name__ == "__main__":
     extreme_events()
